# Enable Python dependency generation
%{?python_enable_dependency_generator}

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

# Missing dependencies for tests
%bcond_with check

# Missing dependencies for documentation
%bcond_with docs

# The master and worker packages have (in theory) an independent versioning
%global workerversion %{version}

Name:           buildbot
Version:        1.1.1
Release:        1%{?dist}

Summary:        Build/test automation system
Group:          Development/Tools
License:        GPLv2
URL:            http://buildbot.net
Source0:        https://files.pythonhosted.org/packages/source/b/%{name}/%{name}-%{version}.tar.gz
Source1:        https://files.pythonhosted.org/packages/source/b/%{name}-worker/%{name}-worker-%{workerversion}.tar.gz
Patch0:		buildbot-master-remove-extrasrequire.patch
Patch1:		buildbot-worker-remove-extrasrequire.patch

BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python2dist(setuptools) >= 8.0
# For Python 3, it requires python3dist(twisted) >= 17.9.0
# c.f.: https://github.com/buildbot/buildbot/blob/v1.0.0/master/setup.py#L458-L461
BuildRequires:  python2dist(twisted) >= 16.1.0
BuildRequires:  python2dist(jinja2) >= 2.1
BuildRequires:  python2dist(zope.interface) >= 4.1.1
BuildRequires:  python2dist(future)
BuildRequires:  python2dist(sqlalchemy) >= 0.8.0
BuildRequires:  python2dist(sqlalchemy-migrate) >= 0.9
BuildRequires:  python2dist(python-dateutil) >= 1.5
BuildRequires:  python2dist(txaio) >= 2.2.2
BuildRequires:  python2dist(autobahn) >= 0.16.0
BuildRequires:  python2dist(pyjwt)

%if %{with check}
BuildRequires:  python2dist(treq)
BuildRequires:  python2dist(txrequests)
BuildRequires:  python2dist(pyjade)
BuildRequires:  python2dist(boto3)
BuildRequires:  python2dist(moto)
BuildRequires:  python2dist(txgithub)
BuildRequires:  python2dist(mock) >= 2.0.0
BuildRequires:  python2dist(lz4)

BuildRequires:  bzr
BuildRequires:  cvs
BuildRequires:  git
BuildRequires:  mercurial
BuildRequires:  subversion
BuildRequires:  darcs
%endif


%if %{with docs}
BuildRequires:  python2dist(sphinx) >= 1.4.0
BuildRequires:  python2dist(sphinxcontrib-blockdiag)
BuildRequires:  python2dist(sphinxcontrib-spelling)
BuildRequires:  python2dist(pyenchant)
BuildRequires:  (python2dist(docutils) >= 0.8 with python2dist(docutils) < 0.13.0)
BuildRequires:  python2dist(sphinx-jinja)
BuildRequires:  python2dist(towncrier)
%endif


# Turns former package into a metapackage for installing everything
Requires:       %{name}-master = %{version}
Requires:       %{name}-worker = %{workerversion}
%if %{with docs}
Requires:       %{name}-doc = %{version}
%else
Obsoletes:      %{name}-doc < %{version}-%{release}
%endif


%description
The BuildBot is a system to automate the compile/test cycle required by
most software projects to validate code changes. By automatically
rebuilding and testing the tree each time something has changed, build
problems are pinpointed quickly, before other developers are
inconvenienced by the failure.


%package master
Summary:        Build/test automation system
Group:          Development/Tools
License:        GPLv2

%if ! %{with docs}
Obsoletes:      %{name}-doc < %{version}-%{release}
%endif

Requires(post): info
Requires(preun): info


%description master
The BuildBot is a system to automate the compile/test cycle required by
most software projects to validate code changes. By automatically
rebuilding and testing the tree each time something has changed, build
problems are pinpointed quickly, before other developers are
inconvenienced by the failure.

This package contains only the buildmaster implementation.
The buildbot-worker package contains the buildworker.


%package worker
Version:        %{workerversion}
Summary:        Build/test automation system
Group:          Development/Tools
License:        GPLv2
Obsoletes:      %{name}-slave < 0.9.0
Provides:       %{name}-slave = %{version}-%{release}

%if ! %{with docs}
Obsoletes:      %{name}-doc < %{version}-%{release}
%endif


%description worker
This package contains only the buildworker implementation.
The buildbot-master package contains the buildmaster.


%if %{with docs}
%package doc
Summary:    Buildbot documentation
Group:      Documentation

%description doc
Buildbot documentation
%endif

%prep
%setup -b1
%patch0 -p0
cd ../%{name}-worker-%{workerversion}
%patch1 -p1


%build
%py2_build

%if %{with docs}
#TODO create API documentation
pushd docs
make docs.tgz VERSION="%{version}" SPHINXBUILD=sphinx-build-2
popd
%endif

pushd ../%{name}-worker-%{workerversion}
%py2_build
popd


%install
%py2_install

mkdir -p %{buildroot}%{_datadir}/%{name}/ \
         %{buildroot}%{_mandir}/man1/ \
         %{buildroot}%{_pkgdocdir}

# install the man page
cp docs/buildbot.1 %{buildroot}%{_mandir}/man1/buildbot.1

%if %{with docs}
# install HTML documentation
tar xf docs/docs.tgz --strip-components=1 -C %{buildroot}%{_pkgdocdir}
%endif

# install worker files
pushd ../%{name}-worker-%{workerversion}
%py2_install

# install the man page
cp docs/buildbot-worker.1 %{buildroot}%{_mandir}/man1/buildbot-worker.1

popd

# Purge windows-only files
rm %{buildroot}%{_bindir}/*windows*

%if %{with check}
%check
trial buildbot.test
%endif


%files
# Empty because metapackage

%files master
%doc CREDITS NEWS UPGRADING
%license COPYING
%{_bindir}/buildbot
%{_mandir}/man1/buildbot.1*
%{python2_sitelib}/buildbot/
%{python2_sitelib}/buildbot-*egg-info/
%{_datadir}/%{name}

%files worker
%doc NEWS UPGRADING
%license COPYING
%{_bindir}/buildbot-worker
%{_mandir}/man1/buildbot-worker.1*
%{python2_sitelib}/buildbot_worker/
%{python2_sitelib}/buildbot_worker-*egg-info/

%if %{with docs}
%files doc
%{_pkgdocdir}/
%endif


%changelog
* Sun Mar 11 2018 Neal Gompa <ngompa13@gmail.com> - 1.1.0-1
- Upgrade to 1.1.0 (#1554094)

* Tue Feb 20 2018 Neal Gompa <ngompa13@gmail.com> - 1.0.0-1
- Rebase to 1.0.0 (#1236345)
- Rename slave subpackage to worker subpackage per upstream rename
- Drop tests and docs as they require several unpackaged dependencies

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.12-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.12-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.12-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.12-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Aug 24 2015 Gianluca Sforna <giallu@gmail.com> 0.8.12-1
- new upstream release
- drop upstreamed patch

* Fri Aug 21 2015 Gianluca Sforna <giallu@gmail.com> 0.8.10-4
- update deps, twisted is now a monolithic package
- fix #1255739: darcs is available on all arch

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Mar  5 2015 Gianluca Sforna <giallu@gmail.com> - 0.8.10-2
- add patch from upstream for # 1199283

* Fri Dec 19 2014 Gianluca Sforna <giallu@gmail.com> - 0.8.10-1
- new upstream release
- remove upstreamed patch

* Mon Sep 29 2014 Gianluca Sforna <giallu@gmail.com> - 0.8.9-1
- new upstream release
- use packages from PyPI

* Tue Jun 24 2014 Yaakov Selkowitz <yselkowi@redhat.com> - 0.8.8-3
- Fix FTBFS due to changes in sphinx and twisted (#1106019)
- Cleanup spec

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Aug 23 2013 Gianluca Sforna <giallu@gmail.com> - 0.8.8-1
- new upstream release

* Mon Aug 05 2013 Gianluca Sforna <giallu@gmail.com> - 0.8.7p1-2
- Install docs to %%{_pkgdocdir} where available.

* Sun Jul 28 2013 Gianluca Sforna <giallu@gmail.com> - 0.8.7p1-1
- New upstream release
- Require python-dateutil

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.6p1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.6p1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jul 18 2012 Gianluca Sforna <giallu@gmail.com> - 0.8.6p1-2
- Add missing require for slave subpackage

* Thu Apr 05 2012 Gianluca Sforna <giallu@gmail.com> - 0.8.6p1-1
- New upstream release

* Mon Mar 12 2012 Gianluca Sforna <giallu@gmail.com> - 0.8.6-2
- New upstream release
- Enable tests again
- Don't test deprecated tla
- Correctly populate -slave subpackage (#736875)
- Fix fetching from git > 1.7.7 (#801209)

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.5p1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Dec 02 2011 Dan Radez <dan@radez.net> - 0.8.5p1-1
- New Upstream Release
- updated make for the docs
- removed the buildbot.info refs added the man page

* Wed Jun 22 2011 Gianluca Sforna <giallu@gmail.com> - 0.8.4p1-2
- Upgrade to 0.8.x
- Add -master and -slave subpackages
- Split html docs in own package

* Mon May 30 2011 Gianluca Sforna <giallu@gmail.com> - 0.7.12-6
- Properly install texinfo files #694199
- Disable tests for now, need to investigate some failures

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.12-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jul 31 2010 Thomas Spura <tomspur@fedoraproject.org> - 0.7.12-4
- Rebuild for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Thu Jul 22 2010 Gianluca Sforna <giallu gmail com> - 0.7.12-3
- Remove BR:bazaar (fixes FTBS)

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 0.7.12-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sun Feb  7 2010 Gianluca Sforna <giallu gmail com>
- Require python-boto for EC2 support
- Require python-twisted-conch for manhole support
- Silence rpmlint

* Fri Jan 22 2010 Gianluca Sforna <giallu gmail com> - 0.7.12-1
- New upstream release

* Mon Aug 17 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 0.7.11p3-1
- Update for another XSS vuln from upstream

* Thu Aug 13 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 0.7.11p2-1
- Update for XSS vuln from upstream

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.11p1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 17 2009 Gianluca Sforna <giallu gmail com> - 0.7.11p1-1
- New upstream release
- Change Source0 URI
- Make tests optional

* Tue Mar  3 2009 Gianluca Sforna <giallu gmail com> - 0.7.10p1-2
- New upstream release
- darcs only avaliable on ix86 platforms 

* Thu Feb 26 2009 Gianluca Sforna <giallu gmail com> - 0.7.10-1
- New upstream release
- Drop upstreamed patch
- Add %%check section and needed BR

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.7-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.7.7-3
- Rebuild for Python 2.6

* Thu Apr  3 2008 Gianluca Sforna <giallu gmail com> - 0.7.7-2
- Fix upgrade path

* Mon Mar 31 2008 Gianluca Sforna <giallu gmail com> - 0.7.7-1
- new upstream release

* Thu Jan  3 2008 Gianluca Sforna <giallu gmail com> - 0.7.6-2
- pick up new .egg file 

* Mon Oct 15 2007 Gianluca Sforna <giallu gmail com> - 0.7.6-1
- new upstream release
- refreshed Patch0
- requires clean up
- License tag update (GPLv2)

* Sat Mar 17 2007 Gianluca Sforna <giallu gmail com>
- Silence rpmlint

* Thu Mar 01 2007 Gianluca Sforna <giallu gmail com> - 0.7.5-1
- new upstream release
- minor spec tweaks
- Removed (unmantained and orphaned) python-cvstoys Require

* Sat Sep 09 2006 Michael J. Knox <michael[AT]knox.net.nz> - 0.7.4-2
- cleanup %%files

* Fri Sep 08 2006 Michael J. Knox <michael[AT]knox.net.nz> - 0.7.4-1
- Upstream update
- don't ghost pyo files

* Fri Jul 28 2006 Michael J. Knox <michael[AT]knox.net.nz> - 0.7.3-3
- move contribs to %%{_datadir}/%%{name}

* Fri Jul 07 2006 Michael J. Knox <michael[AT]knox.net.nz> - 0.7.3-2
- fixes for review
- added patch to remove #! where its not needed (shutup rpmlint)

* Fri Jun 02 2006 Michael J. Knox <michael[AT]knox.net.nz> - 0.7.3-1
- Inital build for FE
